@@ -1,3 +1,6 @@
+from sqlalchemy import BIGINT, Column, String
+from notecoin.huobi.connection.impl import session
+import time
 from notecoin.database.base import Base, BaseTable
 from sqlalchemy import BIGINT, Column, Float, String
 
@@ -48,3 +51,31 @@ class OkexSocketPublicTickers(Base, BaseTable):
 
     def __repr__(self):
         return f"instType{self.instType},instId:{self.instId}"
+
+
+class OkexWebsocketChannels(Base, BaseTable):
+    __tablename__ = 'okex_websocket_channels'
+    channel_json = Column(String(120), comment='channel_json', primary_key=True)
+    channel = Column(String(20), comment='channel')
+    instType = Column(String(20), comment='instType')
+    instId = Column(String(20), comment='instId')
+    updateTime = Column(BIGINT, comment='updateTime')
+
+    def __init__(self, *args, **kwargs):
+        self.channel_json = kwargs.get("channel_json")
+        self.channel = kwargs.get("channel")
+        self.instType = kwargs.get("instType")
+        self.instId = kwargs.get("instId")
+        self.updateTime = int(time.time() * 1000)
+
+    @staticmethod
+    def delete_dated():
+        try:
+            update_time = int(round(time.time() * 1000)) - 60 * 60 * 1000
+            # 先查询，后删除
+            session.query(OkexWebsocketChannels).filter(OkexWebsocketChannels.updateTime < update_time).delete()
+            session.commit()
+            return {"delete success"}
+        except Exception as e:
+            session.rollback()
+            return {"delete error": str(e)}
